// Copyright (c) 2019,  The ZumCoin Developers
//
// Please see the included LICENSE file for more information.

'use strict'

const ZumCoind = require('./')
const util = require('util')

var daemon = new ZumCoind({
  loadCheckpoints: './checkpoints.csv'
  // Load additional daemon parameters here
})

function log (message) {
  console.log(util.format('%s: %s', (new Date()).toUTCString(), message))
}

daemon.on('start', (args) => {
  log(util.format('ZumCoind has started... %s', args))
})

daemon.on('started', () => {
  log('ZumCoind is attempting to synchronize with the network...')
})

daemon.on('syncing', (info) => {
  log(util.format('ZumCoind has synchronized %s out of %s blocks [%s%]', info.height, info.network_height, info.percent))
})

daemon.on('synced', () => {
  log('ZumCoind is synchronized with the network...')
})

daemon.on('ready', (info) => {
  log(util.format('ZumCoind is waiting for connections at %s @ %s - %s H/s', info.height, info.difficulty, info.globalHashRate))
})

daemon.on('desync', (daemon, network, deviance) => {
  log(util.format('ZumCoind is currently off the blockchain by %s blocks. Network: %s  Daemon: %s', deviance, network, daemon))
})

daemon.on('down', () => {
  log('ZumCoind is not responding... stopping process...')
  daemon.stop()
})

daemon.on('stopped', (exitcode) => {
  log(util.format('ZumCoind has closed (exitcode: %s)... restarting process...', exitcode))
  daemon.start()
})

daemon.on('info', (info) => {
  log(info)
})

daemon.on('error', (err) => {
  log(err)
})

daemon.start()
